darkhistory.history.tla.compton_cooling_rate — DarkHistory documentation

# darkhistory.history.tla.compton_cooling_rate

`darkhistory.history.tla.` `compton_cooling_rate`(xHII, xHeII, xHeIII, T_m, rs)

  Returns the Compton cooling rate.

  Parameters: | xHII : float n_HII/n_H. xHeII : float n_HeII/n_H. xHeIII : float n_HeIII/n_H. T_m : float The matter temperature. rs : float The redshift in 1+z.
  Returns: | float The Compton cooling rate in eV/s.

  Notes

  This is the energy loss rate, not the temperature loss rate.

#### Previous topic

darkhistory.history.tla

#### Next topic

darkhistory.history.tla.get_history

### This Page

Show Source